package model.geography;

/**
 * The City class is a simple shape class that
 * models a City.
 *
 * Example Usage:
 *
 * 	City city;
 *  city = City.fromNameLatLong("Brooklyn Center", 45.076076, -93.332728);
 * 	prn(city.toString());
 * */
public class City {

	private String name;
	private GeoLocation location;	

	//------------------------------------------
	// Constructing - public	
	
	/** Returns new City object with passed lat and long values */
	public static City fromNameLatLong(String name, double lat, double lon) {
		return new City(name, lat, lon);
	}	
	
	/** Returns new City object with name "Unnamed" and location (0, 0) */
	public static City newInstance() {
		return fromNameLatLong("Unnamed", 0, 0);
	}		

	//------------------------------------------
	// Constructing - private

	/** Constructs GeoLocation with passed lat and long values */
	private City(String nm, double lat, double lon) {
		this.name = nm;
		this.location = GeoLocation.newInstance();
		this.location.setLatitude(lat);
		this.location.setLongitude(lon);
	}

	//------------------------------------------
	//Calculations
	
	/** Returns true if this location is in the northern hemisphere */
	public boolean isInNorthernHemisphere() {
		return this.location.isInNorthernHemisphere();
	}	
	
	/** Returns true if this location is north of passed latitude */
	public boolean isNorthOf(double aLatitude) {
		return this.location.isNorthOf(aLatitude);
	}		
	
	/** Returns true if this location is south of passed latitude */
	public boolean isSouthOf(double aLatitude) {
		return this.location.isSouthOf(aLatitude);
	}	

	//------------------------------------------
	//Common

	/** Returns nice display string for this City */
	public String toString() {
		return String.format("%s %s",
				this.name.toString(),
				this.location.toString());
	}

}